Sync

Trait Sync 

1.6.0 ยท Source
pub unsafe auto trait Sync { }
Types for which it is safe to share references between threads.

This trait is automatically implemented when the compiler determines itโ€™s appropriate.

The precise definition is: a type T is Sync if and only if &T is Send. In other words, if there is no possibility of undefined behavior (including data races) when passing &T references between threads.

As one would expect, primitive types like u8 and f64 are all Sync, and so are simple aggregate types containing them, like tuples, structs and enums. More examples of basic Sync types include โ€œimmutableโ€ types like &T, and those with simple inherited mutability, such as Box<T>, Vec<T> and most other collection types. (Generic parameters need to be Sync for their container to be Sync.)

A somewhat surprising consequence of the definition is that &mut T is Sync (if T is Sync) even though it seems like that might provide unsynchronized mutation. The trick is that a mutable reference behind a shared reference (that is, & &mut T) becomes read-only, as if it were a & &T. Hence there is no risk of a data race.

A shorter overview of how Sync and Send relate to referencing:

  • &T is Send if and only if T is Sync
  • &mut T is Send if and only if T is Send
  • &T and &mut T are Sync if and only if T is Sync

Types that are not Sync are those that have โ€œinterior mutabilityโ€ in a non-thread-safe form, such as Cell and RefCell. These types allow for mutation of their contents even through an immutable, shared reference. For example the set method on Cell<T> takes &self, so it requires only a shared reference &Cell<T>. The method performs no synchronization, thus Cell cannot be Sync.

Another example of a non-Sync type is the reference-counting pointer Rc. Given any reference &Rc<T>, you can clone a new Rc<T>, modifying the reference counts in a non-atomic way.

For cases when one does need thread-safe interior mutability, Rust provides atomic data types, as well as explicit locking via sync::Mutex and sync::RwLock. These types ensure that any mutation cannot cause data races, hence the types are Sync. Likewise, sync::Arc provides a thread-safe analogue of Rc.

Any types with interior mutability must also use the cell::UnsafeCell wrapper around the value(s) which can be mutated through a shared reference. Failing to doing this is undefined behavior. For example, transmute-ing from &T to &mut T is invalid.

See the Nomicon for more details about Sync.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

1.0.0 ยท Source

impl !Sync for Arguments<'_>

Source

impl !Sync for LocalWaker

Source

impl Sync for core::ffi::c_str::Bytes<'_>

1.10.0 ยท Source

impl Sync for Location<'_>

1.0.0 ยท Source

impl Sync for TypeId

1.36.0 ยท Source

impl Sync for Waker

1.44.0 ยท Source

impl<'a> Sync for IoSlice<'a>

1.44.0 ยท Source

impl<'a> Sync for IoSliceMut<'a>

Source

impl<Dyn: PointeeSized> Sync for DynMetadata<Dyn>

Source

impl<T: ?Sized + Sync> Sync for SyncUnsafeCell<T>

Source

impl<T: ?Sized + Sync> Sync for UnsafePinned<T>

1.0.0 ยท Source

impl<T: ?Sized> !Sync for Cell<T>

Source

impl<T: ?Sized> !Sync for CovariantUnsafeCell<T>

1.0.0 ยท Source

impl<T: ?Sized> !Sync for RefCell<T>

1.0.0 ยท Source

impl<T: ?Sized> !Sync for UnsafeCell<T>

Source

impl<T: ?Sized> Sync for SyncView<T>

1.0.0 ยท Source

impl<T: AtomicPrimitive> Sync for Atomic<T>

1.0.0 ยท Source

impl<T: PointeeSized> !Sync for *const T

1.0.0 ยท Source

impl<T: PointeeSized> !Sync for *mut T

1.25.0 ยท Source

impl<T: PointeeSized> !Sync for NonNull<T>

NonNull pointers are not Sync because the data they reference may be aliased.

1.0.0 ยท Source

impl<T: Sync> Sync for core::slice::Iter<'_, T>

1.0.0 ยท Source

impl<T: Sync> Sync for core::slice::IterMut<'_, T>

1.70.0 ยท Source

impl<T> !Sync for OnceCell<T>

1.31.0 ยท Source

impl<T> Sync for ChunksExactMut<'_, T>
where T: Sync,

1.0.0 ยท Source

impl<T> Sync for ChunksMut<'_, T>
where T: Sync,

1.28.0 ยท Source

impl<T> Sync for NonZero<T>

1.31.0 ยท Source

impl<T> Sync for RChunksExactMut<'_, T>
where T: Sync,

1.31.0 ยท Source

impl<T> Sync for RChunksMut<'_, T>
where T: Sync,

Auto implementors



impl !Sync for RawWaker



impl Sync for Abi



impl Sync for AddrParseError



impl Sync for core::mem::Alignment



impl Sync for core::fmt::Alignment



impl Sync for AllocError



impl Sync for Array



impl Sync for AsciiChar



impl Sync for Assume



impl Sync for AtomicOrdering



impl Sync for BasicBlock



impl Sync for BorrowError



impl Sync for BorrowMutError



impl Sync for ByteStr



impl Sync for CStr



impl Sync for CharCase



impl Sync for CharTryFromError



impl Sync for Const



impl Sync for CpuidResult



impl Sync for DebugAsHex



impl Sync for DecodeUtf16Error



impl Sync for Duration



impl Sync for DynTrait



impl Sync for DynTraitPredicate



impl Sync for core::io::Empty



impl Sync for core::io::Error



impl Sync for core::fmt::Error



impl Sync for ErrorKind



impl Sync for core::char::EscapeDebug



impl Sync for core::ascii::EscapeDefault



impl Sync for core::char::EscapeDefault



impl Sync for core::char::EscapeUnicode



impl Sync for FieldId



impl Sync for FnPtr



impl Sync for FormattingOptions



impl Sync for FpCategory



impl Sync for FromBytesUntilNulError



impl Sync for FromBytesWithNulError



impl Sync for Generic



impl Sync for GenericType



impl Sync for GetDisjointMutError



impl Sync for core::arch::hexagon::v64::HvxVector



impl Sync for core::arch::hexagon::v128::HvxVector



impl Sync for core::arch::hexagon::v64::HvxVectorPair



impl Sync for core::arch::hexagon::v128::HvxVectorPair



impl Sync for core::arch::hexagon::v64::HvxVectorPred



impl Sync for core::arch::hexagon::v128::HvxVectorPred



impl Sync for Infallible



impl Sync for IntErrorKind



impl Sync for IpAddr



impl Sync for Ipv4Addr



impl Sync for Ipv6Addr



impl Sync for Ipv6MulticastScope



impl Sync for Last



impl Sync for Layout



impl Sync for LayoutError



impl Sync for Lifetime



impl Sync for Locality



impl Sync for OneSidedRangeBound



impl Sync for core::cmp::Ordering



impl Sync for core::sync::atomic::Ordering



impl Sync for ParseBoolError



impl Sync for ParseCharError



impl Sync for ParseFloatError



impl Sync for ParseIntError



impl Sync for PhantomPinned



impl Sync for Pointer



impl Sync for RangeFull



impl Sync for RawWakerVTable



impl Sync for Reference



impl Sync for core::io::Repeat



impl Sync for ReturnToArg



impl Sync for SY



impl Sync for SearchStep



impl Sync for SeekFrom



impl Sync for Sign



impl Sync for SimdAlign



impl Sync for Sink



impl Sync for SipHasher



impl Sync for Slice



impl Sync for SocketAddr



impl Sync for SocketAddrV4



impl Sync for SocketAddrV6



impl Sync for Str



impl Sync for ToCasefold



impl Sync for ToLowercase



impl Sync for ToTitlecase



impl Sync for ToUppercase



impl Sync for Trait



impl Sync for TryFromCharError



impl Sync for TryFromFloatSecsError



impl Sync for TryFromIntError



impl Sync for TryFromSliceError



impl Sync for Type



impl Sync for TypeKind



impl Sync for UnwindActionArg



impl Sync for UnwindTerminateReason



impl Sync for Utf8Error



impl Sync for VariantId



impl Sync for __m128



impl Sync for __m256



impl Sync for __m512



impl Sync for __m128bh



impl Sync for __m128d



impl Sync for __m128h



impl Sync for __m128i



impl Sync for __m256bh



impl Sync for __m256d



impl Sync for __m256h



impl Sync for __m256i



impl Sync for __m512bh



impl Sync for __m512d



impl Sync for __m512h



impl Sync for __m512i



impl Sync for __tile1024i



impl Sync for bf16



impl Sync for c_void



impl Sync for f16x2



impl Sync for float16x4_t



impl Sync for float16x4x2_t



impl Sync for float16x4x3_t



impl Sync for float16x4x4_t



impl Sync for float16x8_t



impl Sync for float16x8x2_t



impl Sync for float16x8x3_t



impl Sync for float16x8x4_t



impl Sync for float32x2_t



impl Sync for float32x2x2_t



impl Sync for float32x2x3_t



impl Sync for float32x2x4_t



impl Sync for float32x4_t



impl Sync for float32x4x2_t



impl Sync for float32x4x3_t



impl Sync for float32x4x4_t



impl Sync for float64x1_t



impl Sync for float64x1x2_t



impl Sync for float64x1x3_t



impl Sync for float64x1x4_t



impl Sync for float64x2_t



impl Sync for float64x2x2_t



impl Sync for float64x2x3_t



impl Sync for float64x2x4_t



impl Sync for int8x8_t



impl Sync for int8x8x2_t



impl Sync for int8x8x3_t



impl Sync for int8x8x4_t



impl Sync for int8x16_t



impl Sync for int8x16x2_t



impl Sync for int8x16x3_t



impl Sync for int8x16x4_t



impl Sync for int16x4_t



impl Sync for int16x4x2_t



impl Sync for int16x4x3_t



impl Sync for int16x4x4_t



impl Sync for int16x8_t



impl Sync for int16x8x2_t



impl Sync for int16x8x3_t



impl Sync for int16x8x4_t



impl Sync for int32x2_t



impl Sync for int32x2x2_t



impl Sync for int32x2x3_t



impl Sync for int32x2x4_t



impl Sync for int32x4_t



impl Sync for int32x4x2_t



impl Sync for int32x4x3_t



impl Sync for int32x4x4_t



impl Sync for int64x1_t



impl Sync for int64x1x2_t



impl Sync for int64x1x3_t



impl Sync for int64x1x4_t



impl Sync for int64x2_t



impl Sync for int64x2x2_t



impl Sync for int64x2x3_t



impl Sync for int64x2x4_t



impl Sync for m128



impl Sync for m256



impl Sync for m128d



impl Sync for m128i



impl Sync for m256d



impl Sync for m256i



impl Sync for objc_class



impl Sync for objc_selector



impl Sync for poly8x8_t



impl Sync for poly8x8x2_t



impl Sync for poly8x8x3_t



impl Sync for poly8x8x4_t



impl Sync for poly8x16_t



impl Sync for poly8x16x2_t



impl Sync for poly8x16x3_t



impl Sync for poly8x16x4_t



impl Sync for poly16x4_t



impl Sync for poly16x4x2_t



impl Sync for poly16x4x3_t



impl Sync for poly16x4x4_t



impl Sync for poly16x8_t



impl Sync for poly16x8x2_t



impl Sync for poly16x8x3_t



impl Sync for poly16x8x4_t



impl Sync for poly64x1_t



impl Sync for poly64x1x2_t



impl Sync for poly64x1x3_t



impl Sync for poly64x1x4_t



impl Sync for poly64x2_t



impl Sync for poly64x2x2_t



impl Sync for poly64x2x3_t



impl Sync for poly64x2x4_t



impl Sync for svbool_t



impl Sync for svfloat32_t



impl Sync for svfloat32x2_t



impl Sync for svfloat32x3_t



impl Sync for svfloat32x4_t



impl Sync for svfloat64_t



impl Sync for svfloat64x2_t



impl Sync for svfloat64x3_t



impl Sync for svfloat64x4_t



impl Sync for svint8_t



impl Sync for svint8x2_t



impl Sync for svint8x3_t



impl Sync for svint8x4_t



impl Sync for svint16_t



impl Sync for svint16x2_t



impl Sync for svint16x3_t



impl Sync for svint16x4_t



impl Sync for svint32_t



impl Sync for svint32x2_t



impl Sync for svint32x3_t



impl Sync for svint32x4_t



impl Sync for svint64_t



impl Sync for svint64x2_t



impl Sync for svint64x3_t



impl Sync for svint64x4_t



impl Sync for svpattern



impl Sync for svprfop



impl Sync for svuint8_t



impl Sync for svuint8x2_t



impl Sync for svuint8x3_t



impl Sync for svuint8x4_t



impl Sync for svuint16_t



impl Sync for svuint16x2_t



impl Sync for svuint16x3_t



impl Sync for svuint16x4_t



impl Sync for svuint32_t



impl Sync for svuint32x2_t



impl Sync for svuint32x3_t



impl Sync for svuint32x4_t



impl Sync for svuint64_t



impl Sync for svuint64x2_t



impl Sync for svuint64x3_t



impl Sync for svuint64x4_t



impl Sync for uint8x8_t



impl Sync for uint8x8x2_t



impl Sync for uint8x8x3_t



impl Sync for uint8x8x4_t



impl Sync for uint8x16_t



impl Sync for uint8x16x2_t



impl Sync for uint8x16x3_t



impl Sync for uint8x16x4_t



impl Sync for uint16x4_t



impl Sync for uint16x4x2_t



impl Sync for uint16x4x3_t



impl Sync for uint16x4x4_t



impl Sync for uint16x8_t



impl Sync for uint16x8x2_t



impl Sync for uint16x8x3_t



impl Sync for uint16x8x4_t



impl Sync for uint32x2_t



impl Sync for uint32x2x2_t



impl Sync for uint32x2x3_t



impl Sync for uint32x2x4_t



impl Sync for uint32x4_t



impl Sync for uint32x4x2_t



impl Sync for uint32x4x3_t



impl Sync for uint32x4x4_t



impl Sync for uint64x1_t



impl Sync for uint64x1x2_t



impl Sync for uint64x1x3_t



impl Sync for uint64x1x4_t



impl Sync for uint64x2_t



impl Sync for uint64x2x2_t



impl Sync for uint64x2x3_t



impl Sync for uint64x2x4_t



impl Sync for v128



impl Sync for core::arch::powerpc::vector_bool_char



impl Sync for core::arch::s390x::vector_bool_char



impl Sync for core::arch::powerpc::vector_bool_int



impl Sync for core::arch::s390x::vector_bool_int



impl Sync for vector_bool_long



impl Sync for vector_bool_long_long



impl Sync for core::arch::powerpc::vector_bool_short



impl Sync for core::arch::s390x::vector_bool_short



impl Sync for core::arch::powerpc::vector_double



impl Sync for core::arch::s390x::vector_double



impl Sync for core::arch::powerpc::vector_float



impl Sync for core::arch::s390x::vector_float



impl Sync for core::arch::powerpc::vector_signed_char



impl Sync for core::arch::s390x::vector_signed_char



impl Sync for core::arch::powerpc::vector_signed_int



impl Sync for core::arch::s390x::vector_signed_int



impl Sync for vector_signed_long



impl Sync for vector_signed_long_long



impl Sync for core::arch::powerpc::vector_signed_short



impl Sync for core::arch::s390x::vector_signed_short



impl Sync for core::arch::powerpc::vector_unsigned_char



impl Sync for core::arch::s390x::vector_unsigned_char



impl Sync for core::arch::powerpc::vector_unsigned_int



impl Sync for core::arch::s390x::vector_unsigned_int



impl Sync for vector_unsigned_long



impl Sync for vector_unsigned_long_long



impl Sync for core::arch::powerpc::vector_unsigned_short



impl Sync for core::arch::s390x::vector_unsigned_short



impl<'a, 'b, const N: usize> Sync for CharArrayRefSearcher<'a, 'b, N>
where <MultiCharEqPattern<&'b [char; N]> as Pattern>::Searcher<'a>: Sync,



impl<'a, 'b> !Sync for DebugList<'a, 'b>



impl<'a, 'b> !Sync for DebugMap<'a, 'b>



impl<'a, 'b> !Sync for DebugSet<'a, 'b>



impl<'a, 'b> !Sync for DebugStruct<'a, 'b>



impl<'a, 'b> !Sync for DebugTuple<'a, 'b>



impl<'a, 'b> Sync for CharSliceSearcher<'a, 'b>



impl<'a, 'b> Sync for StrSearcher<'a, 'b>



impl<'a, A> Sync for core::option::Iter<'a, A>
where Item<&'a A>: Sync,



impl<'a, A> Sync for core::option::IterMut<'a, A>
where Item<&'a mut A>: Sync,



impl<'a, F> Sync for CharPredicateSearcher<'a, F>
where <MultiCharEqPattern<F> as Pattern>::Searcher<'a>: Sync,



impl<'a, I> Sync for ByRefSized<'a, I>
where &'a mut I: Sync,



impl<'a, P> Sync for MatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Sync,



impl<'a, P> Sync for Matches<'a, P>
where MatchesInternal<'a, P>: Sync,



impl<'a, P> Sync for RMatchIndices<'a, P>
where MatchIndicesInternal<'a, P>: Sync,



impl<'a, P> Sync for RMatches<'a, P>
where MatchesInternal<'a, P>: Sync,



impl<'a, P> Sync for core::str::RSplit<'a, P>
where SplitInternal<'a, P>: Sync,



impl<'a, P> Sync for core::str::RSplitN<'a, P>
where SplitNInternal<'a, P>: Sync,



impl<'a, P> Sync for RSplitTerminator<'a, P>
where SplitInternal<'a, P>: Sync,



impl<'a, P> Sync for core::str::Split<'a, P>
where SplitInternal<'a, P>: Sync,



impl<'a, P> Sync for core::str::SplitInclusive<'a, P>
where SplitInternal<'a, P>: Sync,



impl<'a, P> Sync for core::str::SplitN<'a, P>
where SplitNInternal<'a, P>: Sync,



impl<'a, P> Sync for SplitTerminator<'a, P>
where SplitInternal<'a, P>: Sync,



impl<'a, T, P> Sync for ChunkBy<'a, T, P>
where &'a [T]: Sync, P: Sync,



impl<'a, T, P> Sync for ChunkByMut<'a, T, P>
where &'a mut [T]: Sync, P: Sync,



impl<'a, T, P> Sync for core::slice::RSplit<'a, T, P>
where Split<'a, T, P>: Sync,



impl<'a, T, P> Sync for RSplitMut<'a, T, P>
where SplitMut<'a, T, P>: Sync,



impl<'a, T, P> Sync for core::slice::RSplitN<'a, T, P>
where GenericSplitN<RSplit<'a, T, P>>: Sync,



impl<'a, T, P> Sync for RSplitNMut<'a, T, P>
where GenericSplitN<RSplitMut<'a, T, P>>: Sync,



impl<'a, T, P> Sync for core::slice::Split<'a, T, P>
where &'a [T]: Sync, P: Sync,



impl<'a, T, P> Sync for core::slice::SplitInclusive<'a, T, P>
where &'a [T]: Sync, P: Sync,



impl<'a, T, P> Sync for SplitInclusiveMut<'a, T, P>
where &'a mut [T]: Sync, P: Sync,



impl<'a, T, P> Sync for SplitMut<'a, T, P>
where &'a mut [T]: Sync, P: Sync,



impl<'a, T, P> Sync for core::slice::SplitN<'a, T, P>
where GenericSplitN<Split<'a, T, P>>: Sync,



impl<'a, T, P> Sync for SplitNMut<'a, T, P>
where GenericSplitN<SplitMut<'a, T, P>>: Sync,



impl<'a, T, const N: usize> Sync for ArrayWindows<'a, T, N>
where &'a [T]: Sync,



impl<'a, T> !Sync for BorrowedCursor<'a, T>



impl<'a, T> Sync for Chunks<'a, T>
where &'a [T]: Sync,



impl<'a, T> Sync for ChunksExact<'a, T>
where &'a [T]: Sync,



impl<'a, T> Sync for core::result::Iter<'a, T>
where Option<&'a T>: Sync,



impl<'a, T> Sync for core::result::IterMut<'a, T>



impl<'a, T> Sync for RChunks<'a, T>
where &'a [T]: Sync,



impl<'a, T> Sync for RChunksExact<'a, T>
where &'a [T]: Sync,



impl<'a, T> Sync for Windows<'a, T>
where &'a [T]: Sync,



impl<'a, const N: usize> Sync for CharArraySearcher<'a, N>
where <MultiCharEqPattern<[char; N]> as Pattern>::Searcher<'a>: Sync,



impl<'a> !Sync for Context<'a>



impl<'a> !Sync for ContextBuilder<'a>



impl<'a> !Sync for Formatter<'a>



impl<'a> !Sync for PanicInfo<'a>



impl<'a> !Sync for PanicMessage<'a>



impl<'a> !Sync for Request<'a>



impl<'a> !Sync for Source<'a>



impl<'a> !Sync for VaList<'a>



impl<'a> Sync for core::str::Bytes<'a>



impl<'a> Sync for CharIndices<'a>



impl<'a> Sync for CharSearcher<'a>



impl<'a> Sync for Chars<'a>



impl<'a> Sync for EncodeUtf16<'a>



impl<'a> Sync for EscapeAscii<'a>



impl<'a> Sync for core::str::EscapeDebug<'a>



impl<'a> Sync for core::str::EscapeDefault<'a>



impl<'a> Sync for core::str::EscapeUnicode<'a>



impl<'a> Sync for Lines<'a>



impl<'a> Sync for LinesAny<'a>



impl<'a> Sync for PhantomContravariantLifetime<'a>



impl<'a> Sync for PhantomCovariantLifetime<'a>



impl<'a> Sync for PhantomInvariantLifetime<'a>



impl<'a> Sync for SplitAsciiWhitespace<'a>



impl<'a> Sync for SplitWhitespace<'a>



impl<'a> Sync for Utf8Chunk<'a>



impl<'a> Sync for Utf8Chunks<'a>



impl<'a> Sync for Utf8Pattern<'a>



impl<'b, T> !Sync for Ref<'b, T>



impl<'b, T> !Sync for RefMut<'b, T>



impl<'data, T> Sync for BorrowedBuf<'data, T>
where &'data mut [MaybeUninit<T>]: Sync,



impl<A, B> Sync for core::iter::Chain<A, B>
where Option<A>: Sync, Option<B>: Sync,



impl<A, B> Sync for Zip<A, B>
where A: Sync, B: Sync,



impl<A> Sync for core::option::IntoIter<A>
where Item<A>: Sync,



impl<A> Sync for OptionFlatten<A>
where Option<A>: Sync,



impl<A> Sync for RangeFromIter<A>
where A: Sync,



impl<A> Sync for RangeInclusiveIter<A>
where RangeInclusive<A>: Sync,



impl<A> Sync for RangeIter<A>
where Range<A>: Sync,



impl<A> Sync for core::iter::Repeat<A>
where A: Sync,



impl<A> Sync for RepeatN<A>
where Option<RepeatNInner<A>>: Sync,



impl<B, C> Sync for ControlFlow<B, C>
where C: Sync, B: Sync,



impl<F> Sync for core::iter::FromFn<F>
where F: Sync,



impl<F> Sync for core::fmt::FromFn<F>
where F: Sync,



impl<F> Sync for OnceWith<F>
where Option<F>: Sync,



impl<F> Sync for PollFn<F>
where F: Sync,



impl<F> Sync for RepeatWith<F>
where F: Sync,



impl<G> Sync for FromCoroutine<G>
where G: Sync,



impl<H> Sync for BuildHasherDefault<H>
where PhantomData<fn() -> H>: Sync,



impl<I, F, const N: usize> Sync for MapWindows<I, F, N>
where F: Sync, MapWindowsInner<I, N>: Sync,



impl<I, F> Sync for FilterMap<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Inspect<I, F>
where I: Sync, F: Sync,



impl<I, F> Sync for Map<I, F>
where I: Sync, F: Sync,



impl<I, G> Sync for IntersperseWith<I, G>
where G: Sync, Option<<I as Iterator>::Item>: Sync, I: Sync,



impl<I, P> Sync for Filter<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for MapWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for SkipWhile<I, P>
where I: Sync, P: Sync,



impl<I, P> Sync for TakeWhile<I, P>
where I: Sync, P: Sync,



impl<I, St, F> Sync for Scan<I, St, F>
where I: Sync, F: Sync, St: Sync,



impl<I, U, F> Sync for FlatMap<I, U, F>
where FlattenCompat<Map<I, F>, <U as IntoIterator>::IntoIter>: Sync,



impl<I, const N: usize> Sync for ArrayChunks<I, N>
where I: Sync, Option<IntoIter<<I as Iterator>::Item, N>>: Sync,



impl<I> Sync for Cloned<I>
where I: Sync,



impl<I> Sync for Copied<I>
where I: Sync,



impl<I> Sync for Cycle<I>
where I: Sync,



impl<I> Sync for DecodeUtf16<I>
where I: Sync,



impl<I> Sync for Enumerate<I>
where I: Sync,



impl<I> Sync for Flatten<I>
where FlattenCompat<I, <<I as Iterator>::Item as IntoIterator>::IntoIter>: Sync,



impl<I> Sync for FromIter<I>
where I: Sync,



impl<I> Sync for Fuse<I>
where Option<I>: Sync,



impl<I> Sync for Intersperse<I>
where <I as Iterator>::Item: Sized + Sync, Option<<I as Iterator>::Item>: Sync, I: Sync,



impl<I> Sync for Peekable<I>
where I: Sync, Option<Option<<I as Iterator>::Item>>: Sync,



impl<I> Sync for Skip<I>
where I: Sync,



impl<I> Sync for StepBy<I>
where I: Sync,



impl<I> Sync for core::iter::Take<I>
where I: Sync,



impl<Idx> Sync for Clamp<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::Range<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeFrom<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for RangeTo<Idx>
where Idx: Sync,



impl<Idx> Sync for core::ops::RangeToInclusive<Idx>
where Idx: Sync,



impl<Idx> Sync for core::range::RangeToInclusive<Idx>
where Idx: Sync,



impl<P> Sync for MaybeDangling<P>
where P: Sync + ?Sized,



impl<Ptr> Sync for Pin<Ptr>
where Ptr: Sync,



impl<T, E> Sync for Result<T, E>
where T: Sync, E: Sync,



impl<T, F = fn() -> T> !Sync for LazyCell<T, F>



impl<T, F> Sync for DropGuard<T, F>



impl<T, F> Sync for Successors<T, F>
where Option<T>: Sync, F: Sync,



impl<T, U> Sync for core::io::Chain<T, U>
where T: Sync, U: Sync,



impl<T, const N: usize> Sync for core::array::IntoIter<T, N>
where ManuallyDrop<PolymorphicIter<[MaybeUninit<T>; N]>>: Sync,



impl<T, const N: usize> Sync for Mask<T, N>
where Simd<T, N>: Sync,



impl<T, const N: usize> Sync for Simd<T, N>
where [T; N]: Sync,



impl<T, const VARIANT: u32, const FIELD: u32> Sync for FieldRepresentingType<T, VARIANT, FIELD>
where PhantomData<fn(T) -> T>: Sync, T: ?Sized,



impl<T> Sync for AssertUnwindSafe<T>
where T: Sync,



impl<T> Sync for Bound<T>
where T: Sync,



impl<T> Sync for Complex<T>
where T: Sync,



impl<T> Sync for Cursor<T>
where T: Sync,



impl<T> Sync for Discriminant<T>



impl<T> Sync for core::iter::Empty<T>
where PhantomData<fn() -> T>: Sync,



impl<T> Sync for core::result::IntoIter<T>
where Option<T>: Sync,



impl<T> Sync for ManuallyDrop<T>
where MaybeDangling<T>: Sync, T: ?Sized,



impl<T> Sync for MaybeUninit<T>
where ManuallyDrop<T>: Sync,



impl<T> Sync for NumBuffer<T>
where <T as NumBufferTrait>::Buf: Sync, PhantomData<T>: Sync,



impl<T> Sync for Once<T>
where IntoIter<T>: Sync,



impl<T> Sync for Option<T>
where T: Sync,



impl<T> Sync for Pending<T>
where PhantomData<fn() -> T>: Sync,



impl<T> Sync for PhantomContravariant<T>
where PhantomData<fn(T)>: Sync, T: ?Sized,



impl<T> Sync for PhantomCovariant<T>
where PhantomData<fn() -> T>: Sync, T: ?Sized,



impl<T> Sync for PhantomData<T>
where T: ?Sized,



impl<T> Sync for PhantomInvariant<T>
where PhantomData<fn(T) -> T>: Sync, T: ?Sized,



impl<T> Sync for Poll<T>
where T: Sync,



impl<T> Sync for Ready<T>
where Option<T>: Sync,



impl<T> Sync for Rev<T>
where T: Sync,



impl<T> Sync for Reverse<T>
where T: Sync,



impl<T> Sync for Saturating<T>
where T: Sync,



impl<T> Sync for core::io::Take<T>
where T: Sync,



impl<T> Sync for TraitImpl<T>
where DynMetadata<T>: Sync, T: ?Sized,



impl<T> Sync for Wrapping<T>
where T: Sync,



impl<T> Sync for Yeet<T>
where T: Sync,



impl<Y, R> Sync for CoroutineState<Y, R>
where Y: Sync, R: Sync,